@@ -188,15 +188,19 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> DataResult<'a, X, Y> {
     /// Automatically create a tick distribution using the default
     /// tick generators tied to a [`PlotNum`].
     ///
-    pub fn plot(
+    #[allow(clippy::type_complexity)]
+    pub fn plot<A, B, C>(
         self,
-        title: impl Display + 'a,
-        xname: impl Display + 'a,
-        yname: impl Display + 'a,
-    ) -> Plotter<'a, X::IntoIter, Y::IntoIter>
+        title: A,
+        xname: B,
+        yname: C,
+    ) -> Plotter<'a, X::IntoIter, Y::IntoIter, SimplePlotFormatter<A, B, C, X::Fmt, Y::Fmt>>
     where
         X: HasDefaultTicks,
         Y: HasDefaultTicks,
+        A: Display,
+        B: Display,
+        C: Display,
     {
         let (x, xt) = ticks_from_default(&self.boundx);
         let (y, yt) = ticks_from_default(&self.boundy);
@@ -207,14 +211,19 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> DataResult<'a, X, Y> {
     /// Move to final stage in pipeline collecting the title/xname/yname.
     /// Unlike [`DataResult::plot`] User must supply own tick distribution.
     ///
-    pub fn plot_with<XI: IntoIterator<Item = X>, YI: IntoIterator<Item = Y>>(
+    pub fn plot_with<XI, YI, PF>(
         self,
         tickx: TickInfo<XI>,
         ticky: TickInfo<YI>,
-        plot_fmt: impl PlotFmt<X = X, Y = Y> + 'a,
-    ) -> Plotter<'a, XI, YI> {
+        plot_fmt: PF,
+    ) -> Plotter<'a, XI, YI, PF>
+    where
+        XI: IntoIterator<Item = X>,
+        YI: IntoIterator<Item = Y>,
+        PF: PlotFmt<X = X, Y = Y>,
+    {
         Plotter {
-            plot_fmt: Box::new(plot_fmt),
+            plot_fmt,
             plots: self,
             tickx: Some(tickx),
             ticky: Some(ticky),
@@ -583,17 +592,20 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
 ///
 /// Created by [`DataResult::plot`] or [`DataResult::plot_with`]
 ///
-pub struct Plotter<'a, XI: IntoIterator, YI: IntoIterator> {
-    plot_fmt: Box<dyn PlotFmt<X = XI::Item, Y = YI::Item> + 'a>,
+pub struct Plotter<'a, XI: IntoIterator, YI: IntoIterator, PF> {
+    plot_fmt: PF,
     plots: DataResult<'a, XI::Item, YI::Item>,
     tickx: Option<TickInfo<XI>>,
     ticky: Option<TickInfo<YI>>,
 }
 
-impl<'a, XI: IntoIterator, YI: IntoIterator> Plotter<'a, XI, YI>
+impl<'a, XI, YI, PF> Plotter<'a, XI, YI, PF>
 where
+    XI: IntoIterator,
+    YI: IntoIterator,
     XI::Item: PlotNum,
     YI::Item: PlotNum,
+    PF: PlotFmt<X = XI::Item, Y = YI::Item>,
 {
     ///
     /// Use the plot iterators to write out the graph elements.
