@@ -71,7 +71,8 @@ impl TickFormat for FloatTickFmt {
 
 impl HasDefaultTicks for f64 {
     type Fmt = FloatTickFmt;
-    fn generate(bound: &crate::Bound<f64>) -> (TickInfo<f64>, FloatTickFmt) {
+    type IntoIter = Vec<f64>;
+    fn generate(bound: &crate::Bound<f64>) -> (TickInfo<Vec<f64>>, FloatTickFmt) {
         let range = [bound.min, bound.max];
         let ideal_num_steps = bound.ideal_num_steps;
         let dash = bound.dash_info;
